summaryrefslogtreecommitdiffstats
path: root/Source/WebCore/platform/graphics/blackberry/LayerWebKitThread.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'Source/WebCore/platform/graphics/blackberry/LayerWebKitThread.cpp')
-rw-r--r--Source/WebCore/platform/graphics/blackberry/LayerWebKitThread.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/Source/WebCore/platform/graphics/blackberry/LayerWebKitThread.cpp b/Source/WebCore/platform/graphics/blackberry/LayerWebKitThread.cpp
index 42b8bed58..142991cf5 100644
--- a/Source/WebCore/platform/graphics/blackberry/LayerWebKitThread.cpp
+++ b/Source/WebCore/platform/graphics/blackberry/LayerWebKitThread.cpp
@@ -195,11 +195,11 @@ void LayerWebKitThread::setDrawable(bool isDrawable)
void LayerWebKitThread::setNeedsCommit()
{
// Call notifySyncRequired(), which in this implementation plumbs through to
// call scheduleRootLayerCommit() on the WebView, which will cause us to commit
// changes done on the WebKit thread for display on the Compositing thread.
if (m_owner)
- m_owner->notifySyncRequired();
+ m_owner->notifyFlushRequired();
}
void LayerWebKitThread::notifyAnimationStarted(double time)
@@ -195,11 +195,11 @@ void LayerWebKitThread::setDrawable(bool isDrawable)
void LayerWebKitThread::setNeedsCommit()
{
- // Call notifySyncRequired(), which in this implementation plumbs through to
+ // Call notifyFlushRequired(), which in this implementation plumbs through to
// call scheduleRootLayerCommit() on the WebView, which will cause us to commit
// changes done on the WebKit thread for display on the Compositing thread.